Package: fitzRoy
Title: Easily Scrape and Process AFL Data
Version: 1.7.0
Authors@R: 
    c(person(given = "James",
             family = "Day",
             role = c("cre", "aut"),
             email = "jamesthomasday@gmail.com"),
      person(given = "Robert",
             family = "Nguyen",
             role = "aut",
             email = "nguyen.n.robert@gmail.com"),
      person(given = "Matthew",
             family = "Erbs",
             role = "ctb",
             email = "matthew.erbs@merbla.com"),
      person(given = "Oscar",
             family = "Lane",
             role = "aut",
             email = "lane.oscar@gmail.com"),
      person(given = "Jason",
             family = "Zivkovic",
             role = "ctb",
             email = "jaseziv83@gmail.com"),
      person(given = "Jacob", 
             family = "Holden", 
             role = "ctb", 
             email = "jlholden26@gmail.com"))
Description: An easy package for scraping and processing Australia Rules Football (AFL)
    data. 'fitzRoy' provides a range of functions for accessing publicly available data 
    from 'AFL Tables' <https://afltables.com/afl/afl_index.html>, 'Footy Wire' <https://www.footywire.com> and
    'The Squiggle' <https://squiggle.com.au>. Further functions allow for easy processing, 
    cleaning and transformation of this data into formats that can be used for analysis. 
License: MIT + file LICENSE
URL: https://jimmyday12.github.io/fitzRoy/,
        https://github.com/jimmyday12/fitzRoy,
        https://github.com/jimmyday12/fitzroy
BugReports: https://github.com/jimmyday12/fitzRoy/issues
Depends: R (>= 4.1)
Imports: dplyr, httr, jsonlite, lubridate, magrittr, purrr, readr,
        rlang (>= 0.1.2), rvest, stringr (>= 1.3.0), tidyr (>= 1.0.0),
        tidyselect, xml2, tibble, glue, cli, lifecycle, httr2, janitor
Suggests: covr, elo, ggplot2, knitr, rmarkdown, testthat (>= 3.0.0),
        roxygen2, spelling, curl
VignetteBuilder: knitr
ByteCompile: true
Encoding: UTF-8
RoxygenNote: 7.3.2
Language: en-US
Config/testthat/edition: 3
Config/testthat/parallel: true
Config/testthat/start-first: fetch-player-stats, fetch-results,
        fetch-lineup, fetch-fixture, fetch*, helpers-footywire
LazyData: true
NeedsCompilation: no
Packaged: 2026-03-12 10:56:30 UTC; jamesday
Author: James Day [cre, aut],
  Robert Nguyen [aut],
  Matthew Erbs [ctb],
  Oscar Lane [aut],
  Jason Zivkovic [ctb],
  Jacob Holden [ctb]
Maintainer: James Day <jamesthomasday@gmail.com>
Repository: CRAN
Date/Publication: 2026-03-12 12:40:02 UTC
Built: R 4.6.0; ; 2026-04-29 17:34:56 UTC; unix
