# Generated by roxygen2: do not edit by hand

export("%>%")
export(calculate_coaches_vote_possibilities)
export(fetch_awards)
export(fetch_awards_allaustralian)
export(fetch_awards_brownlow)
export(fetch_betting_odds_footywire)
export(fetch_coaches_votes)
export(fetch_fantasy_scores)
export(fetch_fixture)
export(fetch_fixture_afl)
export(fetch_fixture_footywire)
export(fetch_fixture_squiggle)
export(fetch_ladder)
export(fetch_ladder_afl)
export(fetch_ladder_afltables)
export(fetch_ladder_squiggle)
export(fetch_lineup)
export(fetch_lineup_afl)
export(fetch_outofcontract)
export(fetch_outofcontract_footywire)
export(fetch_player_details)
export(fetch_player_details_afl)
export(fetch_player_details_afltables)
export(fetch_player_details_footywire)
export(fetch_player_stats)
export(fetch_player_stats_afl)
export(fetch_player_stats_afltables)
export(fetch_player_stats_footywire)
export(fetch_player_stats_fryzigg)
export(fetch_results)
export(fetch_results_afl)
export(fetch_results_afltables)
export(fetch_results_footywire)
export(fetch_results_squiggle)
export(fetch_rising_star)
export(fetch_score_worm_data)
export(fetch_scores)
export(fetch_squiggle_data)
export(fetch_supercoach_scores)
export(fetch_team_stats)
export(get_afl_cookie)
export(get_aflw_detailed_data)
export(get_aflw_detailed_match_data)
export(get_aflw_round_data)
export(get_aflw_rounds)
export(parse_team_abbr)
export(plot_score_worm)
export(plot_score_worm_totals)
export(replace_teams)
export(replace_venues)
export(team_abr_afl)
export(team_abr_afl2)
importFrom(lifecycle,deprecated)
importFrom(magrittr,"%>%")
importFrom(rlang,.data)
importFrom(tibble,tibble)
